=== modified file 'Makefile'
--- Makefile	2006-07-31 16:19:54 +0000
+++ Makefile	2006-07-31 17:48:17 +0000
@@ -33,10 +33,10 @@
 
 # make bzr.exe for win32 with py2exe
 exe:
-	@echo Make bzr.exe
+	@echo *** Make bzr.exe
 	python setup.py py2exe > py2exe.log
-	copy /Y tools\win32\start_bzr.bat win32_bzr.exe\start_bzr.bat
-	copy /Y tools\win32\bazaar.url win32_bzr.exe\bazaar.url
+	python tools/win32/ostools.py copytodir tools/win32/start_bzr.bat win32_bzr.exe
+	python tools/win32/ostools.py copytodir tools/win32/bazaar.url win32_bzr.exe
 
 # translate txt docs to html
 doc_dir := doc 
@@ -52,15 +52,13 @@
 docs: $(htm_files)
 
 copy_docs: docs
-	copy /Y NEWS win32_bzr.exe\NEWS
-	copy /Y README win32_bzr.exe\README
-	python tools/win32/copy_docs.py
+	python tools/win32/ostools.py copytodir $(htm_files) doc/default.css NEWS README  win32_bzr.exe/doc
 
 # win32 installer for bzr.exe
 installer: exe copy_docs
-	@echo Make windows installer
-	cog.py -d -o tools\win32\bzr.iss tools\win32\bzr.iss.cog
-	iscc /Q tools\win32\bzr.iss
+	@echo *** Make windows installer
+	cog.py -d -o tools/win32/bzr.iss tools/win32/bzr.iss.cog
+	iscc /Q tools/win32/bzr.iss
 
 # win32 python's distutils-based installer
 # require to have python interpreter installed on win32
@@ -70,11 +68,11 @@
 
 # clean on win32 all installer-related files and directories
 clean_win32:
-	if exist build rmdir /S /Q build
-	if exist win32_bzr.exe rmdir /S /Q win32_bzr.exe
-	if exist py2exe.log del /Q py2exe.log
-	if exist doc\*.htm del /Q doc\*.htm
-	if exist doc\bzr_man.txt del /Q doc\bzr_man.txt
-	if exist tools\win32\bzr.iss del /Q tools\win32\bzr.iss
-	if exist bzr-setup*.exe del /Q bzr-setup*.exe
-	if exist dist rmdir /S /Q dist
+	python tools/win32/ostools.py remove build
+	python tools/win32/ostools.py remove win32_bzr.exe
+	python tools/win32/ostools.py remove py2exe.log
+	python tools/win32/ostools.py remove doc/*.htm
+	python tools/win32/ostools.py remove doc/bzr_man.txt
+	python tools/win32/ostools.py remove tools/win32/bzr.iss
+	python tools/win32/ostools.py remove bzr-setup*.exe
+	python tools/win32/ostools.py remove dist

=== removed file 'tools/win32/copy_docs.py'
--- tools/win32/copy_docs.py	2006-06-29 08:41:31 +0000
+++ tools/win32/copy_docs.py	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-import glob
-import os
-import shutil
-
-TGT_DIR = 'win32_bzr.exe/doc'
-
-if not os.path.exists(TGT_DIR):
-    os.makedirs(TGT_DIR)
-
-for i in glob.glob('doc/*.htm'):
-    shutil.copy(i, os.path.join('win32_bzr.exe', i))
-
-CSS = 'doc/default.css'
-if os.path.isfile(CSS):
-    shutil.copy(CSS, os.path.join('win32_bzr.exe', CSS))

=== added file 'tools/win32/ostools.py'
--- tools/win32/ostools.py	1970-01-01 00:00:00 +0000
+++ tools/win32/ostools.py	2006-07-31 17:48:17 +0000
@@ -0,0 +1,85 @@
+#!/usr/bin/python
+
+"""Cross-platform os tools: files/directories manipulations
+Usage:
+
+    ostools.py help
+                    prints this help
+
+    ostools.py copytodir FILES... DIR
+                    copy files to specified directory
+
+    ostools.py remove [FILES...] [DIRS...]
+                    remove files or directories (recursive)
+"""
+
+import glob
+import os
+import shutil
+import sys
+
+
+def main(argv=None):
+    if argv is None:
+        argv = sys.argv[1:]
+
+    if not argv:
+        argv = ['help']
+
+    cmd = argv.pop(0)
+
+    if cmd == 'help':
+        print __doc__
+        return 0
+
+    if cmd == 'copytodir':
+        if len(argv) < 2:
+            print "Usage:  ostools.py copytodir FILES... DIR"
+            return 1
+
+        todir = argv.pop()
+        if not os.path.exists(todir):
+            os.makedirs(todir)
+        if not os.path.isdir(todir):
+            print "Error: Destination is not a directory"
+            return 2
+
+        files = []
+        for possible_glob in argv:
+            files += glob.glob(possible_glob)
+
+        for src in files:
+            dest = os.path.join(todir, os.path.basename(src))
+            shutil.copy(src, dest)
+            print "Copied:", src, "=>", dest
+
+        return 0
+
+    if cmd == 'remove':
+        if len(argv) == 0:
+            print "Usage:  ostools.py remove [FILES...] [DIRS...]"
+            return 1
+
+        filesdirs = []
+        for possible_glob in argv:
+            filesdirs += glob.glob(possible_glob)
+
+        for i in filesdirs:
+            if os.path.isdir(i):
+                shutil.rmtree(i)
+                print "Removed:", i
+            elif os.path.isfile(i):
+                os.remove(i)
+                print "Removed:", i
+            else:
+                print "Not found:", i
+
+        return 0
+
+    print "Usage error"
+    print __doc__
+    return 1
+
+
+if __name__ == "__main__":
+    sys.exit(main())

